@@ -85,7 +85,11 @@ class TestInventory(base.TestCase):
                  'Compute': {
                      'ctlplane': ['y.y.y.1']},
                  'CustomRole': {
-                     'ctlplane': ['z.z.z.1']}}}]}
+                     'ctlplane': ['z.z.z.1']}}},
+            {'output_key': 'VipMap',
+             'output_value': {
+                 'ctlplane': 'x.x.x.4',
+                 'redis': 'x.x.x.6'}}]}
         self.plan_name = 'overcloud'
 
         self.hclient = MagicMock()
@@ -152,16 +156,22 @@ class TestInventory(base.TestCase):
     def test_outputs_iterating_returns_list_of_output_keys(self):
         self.assertEqual(
             {'EnabledServices', 'KeystoneURL', 'ServerIdData',
-             'RoleNetHostnameMap', 'RoleNetIpMap'},
+             'RoleNetHostnameMap', 'RoleNetIpMap', 'VipMap'},
             set([o for o in self.outputs]))
 
     def test_inventory_list(self):
         expected = {'c-0': {'hosts': ['x.x.x.1'],
-                            'vars': {'deploy_server_id': 'a'}},
+                            'vars': {'deploy_server_id': 'a',
+                                     'ctlplane_ip': 'x.x.x.1',
+                                     'enabled_networks': ['ctlplane']}},
                     'c-1': {'hosts': ['x.x.x.2'],
-                            'vars': {'deploy_server_id': 'b'}},
+                            'vars': {'deploy_server_id': 'b',
+                                     'ctlplane_ip': 'x.x.x.2',
+                                     'enabled_networks': ['ctlplane']}},
                     'c-2': {'hosts': ['x.x.x.3'],
-                            'vars': {'deploy_server_id': 'c'}},
+                            'vars': {'deploy_server_id': 'c',
+                                     'ctlplane_ip': 'x.x.x.3',
+                                     'enabled_networks': ['ctlplane']}},
                     'Compute': {
                         'children': ['cp-0'],
                         'vars': {'ansible_ssh_user': 'heat-admin',
@@ -173,16 +183,23 @@ class TestInventory(base.TestCase):
                                  'bootstrap_server_id': 'a',
                                  'role_name': 'Controller'}},
                     'cp-0': {'hosts': ['y.y.y.1'],
-                             'vars': {'deploy_server_id': 'd'}},
+                             'vars': {'deploy_server_id': 'd',
+                                      'ctlplane_ip': 'y.y.y.1',
+                                      'enabled_networks': ['ctlplane']}},
                     'cs-0': {'hosts': ['z.z.z.1'],
-                             'vars': {'deploy_server_id': 'e'}},
+                             'vars': {'deploy_server_id': 'e',
+                                      'ctlplane_ip': 'z.z.z.1',
+                                      'enabled_networks': ['ctlplane']}},
                     'CustomRole': {
                         'children': ['cs-0'],
                         'vars': {'ansible_ssh_user': 'heat-admin',
                                  'bootstrap_server_id': 'a',
                                  'role_name': 'CustomRole'}},
                     'overcloud': {
-                        'children': ['Compute', 'Controller', 'CustomRole']},
+                        'children': ['Compute', 'Controller', 'CustomRole'],
+                        'vars': {
+                            'ctlplane_vip': 'x.x.x.4',
+                            'redis_vip': 'x.x.x.6'}},
                     'undercloud': {
                         'hosts': ['localhost'],
                         'vars': {'ansible_connection': 'local',
@@ -213,11 +230,17 @@ class TestInventory(base.TestCase):
         self.inventory.stack_outputs = self.outputs
 
         expected = {'c-0': {'hosts': ['x.x.x.1'],
-                            'vars': {'deploy_server_id': 'a'}},
+                            'vars': {'deploy_server_id': 'a',
+                                     'ctlplane_ip': 'x.x.x.1',
+                                     'enabled_networks': ['ctlplane']}},
                     'c-1': {'hosts': ['x.x.x.2'],
-                            'vars': {'deploy_server_id': 'b'}},
+                            'vars': {'deploy_server_id': 'b',
+                                     'ctlplane_ip': 'x.x.x.2',
+                                     'enabled_networks': ['ctlplane']}},
                     'c-2': {'hosts': ['x.x.x.3'],
-                            'vars': {'deploy_server_id': 'c'}},
+                            'vars': {'deploy_server_id': 'c',
+                                     'ctlplane_ip': 'x.x.x.3',
+                                     'enabled_networks': ['ctlplane']}},
                     'Compute': {
                         'children': ['cp-0'],
                         'vars': {'ansible_ssh_user': 'my-custom-admin',
@@ -229,16 +252,23 @@ class TestInventory(base.TestCase):
                                  'bootstrap_server_id': 'a',
                                  'role_name': 'Controller'}},
                     'cp-0': {'hosts': ['y.y.y.1'],
-                             'vars': {'deploy_server_id': 'd'}},
+                             'vars': {'deploy_server_id': 'd',
+                                      'ctlplane_ip': 'y.y.y.1',
+                                      'enabled_networks': ['ctlplane']}},
                     'cs-0': {'hosts': ['z.z.z.1'],
-                             'vars': {'deploy_server_id': 'e'}},
+                             'vars': {'deploy_server_id': 'e',
+                                      'ctlplane_ip': 'z.z.z.1',
+                                      'enabled_networks': ['ctlplane']}},
                     'CustomRole': {
                         'children': ['cs-0'],
                         'vars': {'ansible_ssh_user': 'my-custom-admin',
                                  'bootstrap_server_id': 'a',
                                  'role_name': 'CustomRole'}},
                     'overcloud': {
-                        'children': ['Compute', 'Controller', 'CustomRole']},
+                        'children': ['Compute', 'Controller', 'CustomRole'],
+                        'vars': {
+                            'ctlplane_vip': 'x.x.x.4',
+                            'redis_vip': 'x.x.x.6'}},
                     'undercloud': {
                         'hosts': ['localhost'],
                         'vars': {'ansible_connection': 'local',
